@@ -24,7 +24,7 @@ try:
 except ImportError:
     gzip = None
 
-__ver__ = '0.8.6'
+__ver__ = '0.8.7'
 
 log = logging.getLogger(__name__)
 
@@ -415,7 +415,7 @@ class Site(object):
                             http_method=http_method)
 
         try:
-            return json.loads(res)
+            return json.loads(res, object_pairs_hook=OrderedDict)
         except ValueError:
             if res.startswith('MediaWiki API is not enabled for this site.'):
                 raise errors.APIDisabledError
