@@ -36,6 +36,9 @@ class Page(object):
             info = six.next(six.itervalues(info['query']['pages']))
         self._info = info
 
+        if 'invalid' in info:
+            raise mwclient.errors.InvalidPageTitle(info.get('invalidreason'))
+
         self.namespace = info.get('ns', 0)
         self.name = info.get('title', u'')
         if self.namespace:
